@@ -11,11 +11,12 @@ pub(super) mod bitz;
 pub(super) mod bybit;
 pub(super) mod coinbase_pro;
 pub(super) mod deribit;
+pub(super) mod dydx;
 pub(super) mod ftx;
 pub(super) mod gate;
 pub(super) mod huobi;
 pub(super) mod kraken;
 pub(super) mod kucoin;
 pub(super) mod mxc;
-pub(super) mod okex;
+pub(super) mod okx;
 pub(super) mod zbg;
