@@ -41,7 +41,7 @@ pub fn fetch_symbols(exchange: &str, market_type: MarketType) -> Result<Vec<Stri
         "kraken" => exchanges::kraken::fetch_symbols(market_type),
         "kucoin" => exchanges::kucoin::fetch_symbols(market_type),
         "mxc" => exchanges::mxc::fetch_symbols(market_type),
-        "okex" => exchanges::okex::fetch_symbols(market_type),
+        "okx" => exchanges::okx::fetch_symbols(market_type),
         "zbg" => exchanges::zbg::fetch_symbols(market_type),
         _ => panic!("Unsupported exchange {}", exchange),
     }
@@ -82,7 +82,7 @@ pub fn fetch_markets(exchange: &str, market_type: MarketType) -> Result<Vec<Mark
         "kraken" => exchanges::kraken::fetch_markets(market_type),
         "kucoin" => exchanges::kucoin::fetch_markets(market_type),
         "mxc" => exchanges::mxc::fetch_markets(market_type),
-        "okex" => exchanges::okex::fetch_markets(market_type),
+        "okx" => exchanges::okx::fetch_markets(market_type),
         "zbg" => exchanges::zbg::fetch_markets(market_type),
         _ => panic!("Unsupported exchange {}", exchange),
     }
